User prompt
also make boss hp 3
User prompt
when boss destroyed the should be huge explonation using kabom asset
User prompt
make bosses hp 50
User prompt
Please fix the bug: 'TypeError: Cannot read properties of undefined (reading 'intersects')' in or related to this line: 'if (boss && lasers[i].intersects(boss)) {' Line Number: 254
User prompt
so we counter a bug, we can't hit boss right now
User prompt
lets make boss hp equal to other ships for now
User prompt
boss right and left shooter should little bit closer to middle one
User prompt
boss also can shoot lasers from right and left side of their texture
User prompt
make boss hp 50
User prompt
boss spawning score is 3 now
User prompt
make boss bigger
User prompt
half of the boss is going out of screen when its gets to right or left side of screen, because of that lets make boss horizontal movement range little bit shorter
User prompt
boss horizontal movement should be little bit slower
User prompt
everything god but boss can stops at little bit higher
User prompt
when boss gets middle of the screen it stops going down and starts horizontal movement
User prompt
when player gets 10 score and boss spawnes other enemyships stops spawning
User prompt
add boss to game using boss asset but boss only appear when player get score 10
User prompt
make enemies laser x1.5 bigger
User prompt
add explosion sound for destroy
User prompt
i change laser sound make sure you add the new one
User prompt
Please fix the bug: 'Uncaught TypeError: Cannot read properties of undefined (reading 'sound')' in or related to this line: 'LK.init.sound('lasersound').play();' Line Number: 118
Code edit (1 edits merged)
Please save this source code
User prompt
laser sound is gone add it again
User prompt
now another bug , ship that i shoot stays but another one is dissapers
User prompt
bug still alive, you only destroy the ship i shot
===================================================================
--- original.js
+++ change.js
@@ -233,14 +233,14 @@
LK.showGameOver(); // Calling this will destroy the 'Game' and reset entire game state.
break;
}
}
- // Spawn enemies periodically
- if (LK.ticks % 60 == 0) {
+ // Spawn enemies periodically if boss is not present
+ if (!boss && LK.ticks % 60 == 0) {
spawnEnemy();
}
- // Enemies shoot periodically
- if (LK.ticks % 120 == 0) {
+ // Enemies shoot periodically if boss is not present
+ if (!boss && LK.ticks % 120 == 0) {
for (var i = 0; i < enemies.length; i++) {
enemies[i].shoot();
}
}
star white. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
enemy space ship boss it should be big and looking from top. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
explosion. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
linear laser red horizontal. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
red pixel circle with black background and hearth on middle. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
red circle with black background and bullet on middle next to x2 symbol. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.